#
# spec file for package package-update-indicator
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2022 SUSE Software Solutions Germany GmbH, Nuernberg, Germany.
# Copyright (c) 2018 B1 Systems GmbH, Vohburg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           package-update-indicator
Version:        8
Release:        bp155.1.6
Summary:        Package update status notification applet
License:        MIT
Group:          System/Daemons
URL:            https://code.guido-berhoerster.org/projects/package-update-indicator
Source0:        https://code.guido-berhoerster.org/projects/package-update-indicator/downloads/%{name}-%{version}.tar.gz
Source1:        10_opensuse_update_command.gschema.override
Source2:        LICENSE
BuildRequires:  docbook5-xsl-stylesheets
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  gettext >= 0.19
BuildRequires:  gmake >= 3.81
BuildRequires:  pkgconfig
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(appindicator3-0.1) >= 12.10.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.48
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.18
BuildRequires:  pkgconfig(packagekit-glib2) >= 0.8.17
BuildRequires:  pkgconfig(polkit-gobject-1) >= 0.105
BuildRequires:  pkgconfig(upower-glib) >= 0.99.0
Obsoletes:      pk-update-icon <= 3
Recommends:     gnome-packagekit
%glib2_gsettings_schema_requires

%description
The package-update-indicator utility regularly checks for software
updates and notifies the user about available updates using
desktop notifications and either a status notifier icon or a
system tray icon.

It is primarily intended for desktops which do not already have
this functionality built-in, such as Xfce.

%lang_package

%prep
%autosetup
cp -av '%{SOURCE2}' '.'

%build
%make_build 'prefix=%{_prefix}' 'GLIB_COMPILE_SCHEMAS=:' 'CFLAGS=%{optflags}' 'CC=gcc'

%install
%make_install 'prefix=%{_prefix}' 'GLIB_COMPILE_SCHEMAS=:'

# Stage gsettings override into destroot.
install -m 0644 '%{SOURCE1}' '%{buildroot}%{_datadir}/glib-2.0/schemas/'

%fdupes %{buildroot}

%find_lang %{name} %{?no_lang_C}

%files
%license LICENSE
%doc NEWS README
%config %{_sysconfdir}/xdg/autostart/org.guido-berhoerster.code.%{name}.desktop
%{_bindir}/%{name}
%{_bindir}/%{name}-prefs
%{_datadir}/applications/org.guido-berhoerster.code.%{name}.preferences.desktop
%{_datadir}/glib-2.0/schemas/10_opensuse_update_command.gschema.override
%{_datadir}/glib-2.0/schemas/org.guido-berhoerster.code.%{name}.gschema.xml
%{_mandir}/man1/%{name}-prefs.1%{?ext_man}
%{_mandir}/man1/%{name}.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Wed Sep  7 2022 Stefan Seyfried <seife+obs@b1-systems.com>
- Update to version 8:
  * Add setting to disable preferences widgets
  * Fix typos and improve German translations
  * Add new setting to hide indicator menu items
  * Add new setting "always-active"
  * Add Brazilian Portugese translations
  * Add Dutch translations
  * Do not hardcode pkg-config
  * Fix desktop files
  * Remove translated icon names
  * Add Spanish translations
- remove obsolete patch
  org.guido-berhoerster.code.package-update-indicator.desktop.in.patch
- Changes by Mihai Moldovan <ionic@ionic.de>:
  * Update copyright notice.
  * Add properly extracted license.
  * Check destroot with fdupes for good measure.
  * Make some dependencies more explicit and remove duplicate
    ones (xsltproc vs. libxml2-tools).
  * Add glib gsettings schemas macros.
  * Reflow description to 67 characters.
  * Use more (single) quotes.
  * Re-sort files list alphabetically, use %%{name} to avoid
    redundancy.
* Wed Nov 18 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- update to version 7:
  * Explicitly schedule the initial check for updates after a
    fixed short delay
  * Add debug logging when periodic checks are inhibited
  * Add Russian translations
* Mon Aug 24 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- update to version 6:
  * Back out fallback icon support which does not work as intended
  * Add Italian translations
  * Add French translations
  * Add Danish translations
  * Fix incorrect translation
* Wed Jun 10 2020 Vinzenz Vietzke <vinz@vinzv.de>
- Adding patch org.guido-berhoerster.code.package-update-indicator.desktop.in.patch
  fixing package-update-indicator should not start within
  Gnome or KDE (boo#1172623)
* Sun Sep  1 2019 Stefan Seyfried <seife+obs@b1-systems.com>
- update to version 5:
  * Reduce delay before checking for updates after an "updates-
    changed" signal
  * Fix continuos loop of update checks if the refresh cache
    interval is 0
  * Add fallback icons for KDE-based themes
* Wed Jul 24 2019 Stefan Seyfried <seife+obs@b1-systems.com>
- Update to version 4:
  * Use consistent vocabulary in German translations
  * Add support for libayantana-indicator
  * Fix typo in German translations
* Thu Apr 25 2019 Andreas Schwab <schwab@suse.de>
- Remove useless clang dependency
* Tue Apr 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fix Obsoletes: pk-update-icon <= 3
* Sun Apr 14 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Changed to more appropriate Obsoletes: pk-update-icon <= 2
* Fri Apr 12 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Added Obsoletes: pk-update-icon
* Sun Apr  7 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 2:
  * Add keywords to desktop files
  * Fix typo in notification message
  * Do not run glib-compile-schemas if schemas are installed into staging directory
  * Set application indicator title
  * Add note for vendors on how to override default settings
- Added BuildRequires: clang
- Spec file cleanup:
  - Changed URL and Source to https://
  - Use more appropriate macros such as %%autosetup and %%make_build
* Tue Jul 10 2018 seife+obs@b1-systems.com
- add 10_opensuse_update_command.gschema.override for update
  program default
* Mon Jul  9 2018 seife+obs@b1-systems.com
- initial package version 1
